-- ##########################################################################################################################################################
-- #                                                                                                                                                        #
-- #                                                                       MIT License                                                                      #
-- #                                                                                                                                                        #
-- #                                                                                                                                                        #
-- #                                                          Copyright (c) 2025 IG-Development Ingmar Grote                                                #
-- #                                                               Email: i.grote@i-g.de                                                                    #
-- # ------------------------------------------------------------------------------------------------------------------------------------------------------ #
-- # Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),     #
-- # I to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,   #
-- # and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:             #
-- # The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.                         #
-- # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,    #
-- # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,                      #
-- # DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE        #
-- # USE OR OTHER DEALINGS IN THE SOFTWARE.                                                                                                                 #
-- # ------------------------------------------------------------------------------------------------------------------------------------------------------ #
-- #                                                      Sinngemäße Übersetzung (nicht offiziell)                                                          #
-- # Jedem, der eine Kopie dieser Software und der zugehörigen Dokumentationsdateien (die "Software") erhält, wird hiermit kostenlos die Erlaubnis erteilt, #
-- # ohne Einschränkung mit der Software zu handeln, einschließlich und ohne Einschränkung der Rechte zur Nutzung, zum Kopieren, ändern, Zusammenführen,    #
-- # Veröffentlichen, Verteilen, Unterlizenzieren und/oder Verkaufen von Kopien der Software, und Personen, denen die Software zur Verfügung gestellt wird, #
-- # dies unter den folgenden Bedingungen zu gestatten:                                                                                                     #
-- # Der obige Urheberrechtshinweis und dieser Genehmigungshinweis müssen in allen Kopien oder wesentlichen Teilen der Software enthalten sein.             #
-- # DIE SOFTWARE WIRD OHNE MÄNGELGEWÄHR UND OHNE JEGLICHE AUSDRÜCKLICHE ODER STILLSCHWEIGENDE GEWÄHRLEISTUNG, EINSCHLIESSLICH, ABER NICHT BESCHRÄNKT AUF   #
-- # DIE GEWÄHRLEISTUNG DER MARKTGÄNGIGKEIT, DER EIGNUNG FÜR EINEN BESTIMMTEN ZWECK UND DER NICHTVERLETZUNG VON RECHTEN DRITTER, ZUR VERFÜGUNG GESTELLT.    #
-- # DIE AUTOREN ODER URHEBERRECHTSINHABER SIND IN KEINEM FALL HAFTBAR FÜR ANSPRÜCHE, SCHÄDEN ODER ANDERE VERPFLICHTUNGEN, OB IN EINER VERTRAGS- ODER       #
-- # HAFTUNGSKLAGE, EINER UNERLAUBTEN HANDLUNG ODER ANDERWEITIG, DIE SICH AUS, AUS ODER IN VERBINDUNG MIT DER SOFTWARE ODER DER NUTZUNG ODER ANDEREN        #
-- # GESCHÄFTEN MIT DER SOFTWARE ERGEBEN.                                                                                                                   #
-- #                                                                                                                                                        #
-- ##########################################################################################################################################################

-- ##########################################################################################################################################################
-- ##########################################################################################################################################################
-- ##                                                                                                                                                      ##
-- ##                                                                 !!!!!!!! ACHTUNG !!!!!!!!                                                            ##
-- ## JETI weist ausdrücklich darauf hin, Lua-Anwendungen nicht zur Steuerung von Modellfunktionen zu verwenden, welche einen Absturz verursachen können,  ##
-- ## wenn sich die Anwendung nicht richtig verhält oder nicht mehr ausgeführt wird.                                                                       ##
-- ## ---------------------------------------------------------------------------------------------------------------------------------------------------- ##
-- ##                                                   Hier der Originaltext aus der JETI DCDS_Lua_API_1.5:                                               ##
-- ## WARNING                                                                                                                                              ##
-- ## Do not use Lua applications for controlling any model function that could cause a crash if the application misbehaves or stops executing.            ##
-- ## ---------------------------------------------------------------------------------------------------------------------------------------------------- ##
-- ## Bitte beachten sie obenstehende Warnhinweise!                                                                                                        ##
-- ##                                                                                                                                                      ##
-- ##########################################################################################################################################################
-- ##########################################################################################################################################################

collectgarbage()

--[[one
-- nach unbeabsichtigten globalen Variablen suchen
setmetatable(_G, {
	__newindex = function(array, key, value)
		print(string.format("Changed _G: %s = %s", tostring(key), tostring(value)));
		rawset(array, key, value);
	end
});
--]]

-------------------------------------------------------------------------------

local appnamen = "Switch57"
local appversion = "2.01"
local imageLV1, imageRV1, imageLB, imageRB
local trans, model, device, controls, text, switch, value, name, formID, formCenterL, formCenterR, centerL, centerR, options, option, timeB2, timeB3, timeB4
local folder, imageExtensions, transName, transDefault, transExtension = "Apps/Switch57/", {".png", ".jpg"}, "Sw-", "Global", ".jsn"
local option = 1
local knueppelnameLV, knueppelnameLO, knueppelnameRV, knueppelnameRO
local formGrafik, neuegrafik, imageLV2, imageRV2

local function setLanguage()
	local locale = system.getLocale()
	trans        = {}

	if (locale == 'de') then 
		trans.switchlabeling   = "Schalterbeschriftung"
		trans.toggle           = "Ansicht Sender vorne/hinten"
		trans.centerupperleft  = "Text links oben zentriert"
		trans.centerupperright = "Text rechts oben zentriert"
		trans.selectswitch     = "Schalter auswählen"
		trans.label            = "Beschriftung"
		trans.stickswitchlabel = "Zuweisung Knüppelschalter"
		trans.newdesign			= "Neues Grafikdesign verwenden"
		trans.stickswitch_l_front = "Knüppelschalter links vorne ist angeschlossen bei"
		trans.stickswitch_l_top = "Knüppelschalter links oben ist angeschlossen bei"
		trans.stickswitch_r_front = "Knüppelschalter rechts vorne ist angeschlossen bei"
		trans.stickswitch_r_top = "Knüppelschalter rechts oben ist angeschlossen bei"

	elseif (locale == 'it') then 
		trans.switchlabeling   = "Etichettatura interruttori"
		trans.toggle           = "Vista trasmettitore davanti/indietro"
		trans.centerupperleft  = "Testo centrato in alto a sinistra"
		trans.centerupperright = "Testo centrato in alto a destra"
		trans.selectswitch     = "Seleziona interruttore"
		trans.label            = "Etichettatura"
		trans.newdesign 		= "Usa la nuova grafica"
		trans.stickswitchlabel = "Assegnazione degli interruttori a leva"
		trans.stickswitch_l_front = "Interruttore a leva sinistro anteriore è collegato a"
		trans.stickswitch_l_top = "Interruttore a leva sinistro in alto è collegato a"
		trans.stickswitch_r_front = "Interruttore a leva destro anteriore è collegato a"
		trans.stickswitch_r_top = "Interruttore a leva destro in alto è collegato a"

	elseif (locale == 'es') then 
		trans.switchlabeling   = "Nombre interruptor"
		trans.toggle           = "Vista transmisora enfrente/atrás"
		trans.centerupperleft  = "Texto izquierda arriba central"
		trans.centerupperright = "Texto derecha arriba central"
		trans.selectswitch     = "Selección de interruptor"
		trans.label            = "Nombre"
		trans.newdesign 		= "Utilizar nuevo diseño gráfico"
		trans.stickswitchlabel = "Asignación del interruptor de palanca"
		trans.stickswitch_l_front = "El Interruptor de palanca izquierdo frontal está conectado a"
		trans.stickswitch_l_top = "El interruptor de palanca izquierdo superior está conectado a"
		trans.stickswitch_r_front = "El Interruptor de palanca derecho frontal está conectado a"
		trans.stickswitch_r_top = "El interruptor de palanca derecho superior está conectado a"

	else 
		trans.switchlabeling   = "Switch labeling"
		trans.toggle           = "Toggle front/back view"
		trans.centerupperleft  = "Center upper left text"
		trans.centerupperright = "Center upper right text"
		trans.selectswitch     = "Select switch"
		trans.label            = "Label"
		trans.newdesign 		= "Use new graphic design"
		trans.stickswitchlabel = "Stick switch assignment"
		trans.stickswitch_l_front = "Stick switch left front is connected at"
		trans.stickswitch_l_top = "Stick switch left top is connected at"
		trans.stickswitch_r_front = "Stick switch right front is connected at"
		trans.stickswitch_r_top = "Stick switch right top is connected at"

	end
end
--------------------------------------------------------------------------------
-- Read translations
local function loadModel(default)
	local model = model:gsub("[^\32-\126]", "")
	local file
	
	if (not default) then
		file = io.readall(folder..transName..model..transExtension)
	end

	if (not file) then
		file = io.readall(folder..transName..transDefault..transExtension)
	end

	controls = json.decode(file)
	text  = controls[options[option]]
end

-------------------------------------------------------------------------------
local function saveModel(default)
	local text  = json.encode(controls)
	local model = model:gsub("[^\32-\126]", "")
	local file
	
	if (not default) then
		file = io.open(folder..transName..model..transExtension, "w")
	end

	if (not file) then
		file = io.open(folder..transName..transDefault..transExtension, "w")
	end
	
	io.write(file, text)
	io.close(file)
end

-------------------------------------------------------------------------------
local function initModel()
	loadModel(true )
	saveModel(false)
end

-------------------------------------------------------------------------------
local function loadImage(file)
	for _, extension in ipairs(imageExtensions) do
		local image = lcd.loadImage(folder..file..extension)
		if (image) then
			return image
		end
	end
end																														
																					
-------------------------------------------------------------------------------
-- Ansicht vorne links

local function drawPageLA(width, height) 
	local font
	lcd.setColor(255, 255, 255)

	if (device == "JETI DC-24 II" or device == "JETI DS-24 II") then

		if(neuegrafik == true) then 								-- grafik v2 anzeigen

			if (imageLV2 == nil) then
				imageLV2 = loadImage("DC24-2_Schalter_LV2")
			end

			if (imageLV2) then
				lcd.drawImage(0, 0, imageLV2)
			end
			
			font = FONT_BOLD
			lcd.drawText(199, 5,  "SD", font)
			lcd.drawText(199, 27,  "SC", font)
			lcd.drawText(199, 47,  "SA", font)
			lcd.drawText(199, 68,  "SB", font)
			lcd.drawText(199, 90,  "G6", font)
			lcd.drawText(199, 111,  "G8", font)

			font = FONT_NORMAL
			lcd.drawText(1, 4,   controls.SD, font)
			lcd.drawText(1, 25,  controls.SC, font)
			lcd.drawText(1, 46,  controls.SA, font)
			lcd.drawText(1, 67,  controls.SB, font)
			lcd.drawText(1, 88,  controls.G6, font)
			lcd.drawText(1, 109, controls.G8, font)

			font = FONT_BOLD
			-- ausgabe knüppeltext vorne
			lcd.drawText(1, 131, controls[options[knueppelnameLV]], FONT_NORMAL)
			-- ausgabe knüppelname vorne
			lcd.drawText(199, 132,  options[knueppelnameLV], font)

			-- ausgabe knüppeltext oben
			lcd.drawText(1, 152, controls[options[knueppelnameLO]], FONT_NORMAL)
			-- ausgabe knüppelname oben
			lcd.drawText(199, 153,  options[knueppelnameLO], font)
			
			lcd.drawText(199, 174,  "SE", font)
			lcd.drawText(199, 195,  "L1", font)
			lcd.drawText(199, 216,  "L2", font)

			font = FONT_NORMAL
			lcd.drawText(1, 173, controls.SE, font)
			lcd.drawText(1, 194, controls.L1, font)
			lcd.drawText(1, 214, controls.L2, font)
		end -- Ende grafik V2


		
		if (neuegrafik == false) then 								-- grafik V1 anzeigen
			if (imageLV1 == nil) then
				imageLV1 = loadImage("DC24-2_Schalter_L")
			end

			if (imageLV1) then
				lcd.drawImage(0, 0, imageLV1)
			end

			font = FONT_BOLD
			lcd.drawText(1, 5,  "SD", font)
			lcd.drawText(1, 26,  "SC", font)
			lcd.drawText(1, 48,  "SA", font)
			lcd.drawText(1, 68,  "SB", font)
			lcd.drawText(1, 90,  "G6", font)
			lcd.drawText(1, 110,  "G8", font)

			font = FONT_NORMAL
			lcd.drawText(30, 4,   controls.SD, font)
			lcd.drawText(30, 25,  controls.SC, font)
			lcd.drawText(30, 46,  controls.SA, font)
			lcd.drawText(30, 67,  controls.SB, font)
			lcd.drawText(30, 88,  controls.G6, font)
			lcd.drawText(30, 109, controls.G8, font)

			font = FONT_BOLD
			-- ausgabe knüppeltext vorne
			lcd.drawText(30, 131, controls[options[knueppelnameLV]], FONT_NORMAL)
			-- ausgabe knüppelname vorne
			lcd.drawText(1, 131,  options[knueppelnameLV], font)

			-- ausgabe knüppeltext oben
			lcd.drawText(30, 152, controls[options[knueppelnameLO]], FONT_NORMAL)
			-- ausgabe knüppelname oben
			lcd.drawText(1, 152,  options[knueppelnameLO], font)

			lcd.drawText(1, 173, "SE", font)
			lcd.drawText(1, 194, "L1", font)
			lcd.drawText(1, 215, "L2", font)

			font = FONT_NORMAL
			lcd.drawText(30, 173, controls.SE, font)
			lcd.drawText(30, 194, controls.L1, font)
			lcd.drawText(30, 214, controls.L2, font)
	end 															-- Ende grafik V1

	end

	
end

-------------------------------------------------------------------------------
-- Ansicht vorne rechts

local function drawPageRA(width, height)
	local font
	lcd.setColor(255, 255, 255)
	
	if (device == "JETI DC-24 II" or device == "JETI DS-24 II") then

		if(neuegrafik == true) then 								-- grafik v2 anzeigen

			if (imageRV2 == nil) then
				imageRV2 = loadImage("DC24-2_Schalter_RV2")
			end

			if (imageRV2) then
				lcd.drawImage(0, 0, imageRV2)
			end

			font = FONT_BOLD
			lcd.drawText(100, 5,  "SG", font)
			lcd.drawText(100, 27,  "SH", font)
			lcd.drawText(100, 47,  "SJ", font)
			lcd.drawText(100, 68,  "SI", font)
			lcd.drawText(100, 90,  "G5", font)
			lcd.drawText(100, 111,  "G7", font)

			font = FONT_NORMAL
			lcd.drawText(120, 4, controls.SG, font)
			lcd.drawText(120, 25, controls.SH, font)
			lcd.drawText(120, 46, controls.SJ, font)
			lcd.drawText(120,  67, controls.SI, font)
			lcd.drawText(120,  88, controls.G5, font)
			lcd.drawText(120,  109, controls.G7, font)


			font = FONT_BOLD
			-- ausgabe knüppeltext vorne
			lcd.drawText(120, 132, controls[options[knueppelnameRV]], FONT_NORMAL)													
			-- ausgabe knüppelname vorne
			lcd.drawText(92, 132,  options[knueppelnameRV], font)

			-- ausgabe knüppeltext oben
			lcd.drawText(120, 152, controls[options[knueppelnameRO]], FONT_NORMAL)	
			-- ausgabe knüppelname oben
			lcd.drawText(92, 153,  options[knueppelnameRO], font)

			lcd.drawText(100, 174,  "SF", font)
			lcd.drawText(100, 195,  "R1", font)
			lcd.drawText(100, 216,  "R2", font)											

			font = FONT_NORMAL
			lcd.drawText(120,  173, controls.SF, font)
			lcd.drawText(120,  194, controls.R1, font)
			lcd.drawText(120,  214, controls.R2, font)
		end 														-- Ende grafik V2

		if (neuegrafik == false) then 								-- grafik V1 anzeigen
			if (imageRV1 == nil) then
				imageRV1 = loadImage("DC24-2_Schalter_R")
			end

			if (imageRV1) then
				lcd.drawImage(0, 0, imageRV1)
			end

			font = FONT_BOLD
			lcd.drawText(290, 5,  "SG", font)
			lcd.drawText(290, 26,  "SH", font)
			lcd.drawText(290, 48,  "SJ", font)
			lcd.drawText(290, 68,  "SI", font)
			lcd.drawText(290, 90,  "G5", font)
			lcd.drawText(290, 110,  "G7", font)

			font = FONT_NORMAL
			lcd.drawText(284 - lcd.getTextWidth(font, controls.SG),   4, controls.SG, font)
			lcd.drawText(284 - lcd.getTextWidth(font, controls.SH),   25, controls.SH, font)
			lcd.drawText(284 - lcd.getTextWidth(font, controls.SJ),   46, controls.SJ, font)
			lcd.drawText(284 - lcd.getTextWidth(font, controls.SI),   67, controls.SI, font)
			lcd.drawText(284 - lcd.getTextWidth(font, controls.G5),   88, controls.G5, font)
			lcd.drawText(284 - lcd.getTextWidth(font, controls.G7),   109, controls.G7, font)

			font = FONT_BOLD
			-- ausgabe knüppeltext vorne
			lcd.drawText(284 - lcd.getTextWidth(font, controls[options[knueppelnameRV]]),   131, controls[options[knueppelnameRV]], FONT_NORMAL)
			-- ausgabe knüppelname vorne
			lcd.drawText(290, 131,  options[knueppelnameRV], font)

			-- ausgabe knüppeltext oben
			lcd.drawText(284 - lcd.getTextWidth(font, controls[options[knueppelnameRO]]),   152, controls[options[knueppelnameRO]], FONT_NORMAL)
			-- ausgabe knüppelname oben
			lcd.drawText(290, 152,  options[knueppelnameRO], font)


			lcd.drawText(290, 173, "SF", font)
			lcd.drawText(290, 194, "R1", font)
			lcd.drawText(290, 215, "R2", font)

			font = FONT_NORMAL
			lcd.drawText(284 - lcd.getTextWidth(font, controls.SF),   173, controls.SF, font)
			lcd.drawText(284 - lcd.getTextWidth(font, controls.R1),   194, controls.R1, font)
			lcd.drawText(284 - lcd.getTextWidth(font, controls.R2),   214, controls.R2, font)

		end 														-- Ende grafik V1

	end
end

-------------------------------------------------------------------------------
-- Ansicht hinte links

local function drawPageLB(width, height)
	local font
	lcd.setColor(255, 255, 255)

	if (device == "JETI DC-24 II" or device == "JETI DS-24 II") then

		if (imageLB == nil) then
			imageLB = loadImage("DC24-2_Schalter_L_RS")
		end

		if (imageLB) then
			lcd.drawImage(0, 0, imageLB)
		end

		font = FONT_BOLD
			lcd.drawText(296, 5,  "L3", font)
			lcd.drawText(296, 26,  "L4", font)
			lcd.drawText(296, 48,  "L5", font)
			lcd.drawText(296, 68,  "L6", font)
			lcd.drawText(296, 90,  "L7", font)

		font = FONT_NORMAL
		if (centerL) then		
			lcd.drawText(200 - (lcd.getTextWidth(font, controls.L3) / 2),   4,  controls.L3, font)
			lcd.drawText(200 - (lcd.getTextWidth(font, controls.L4) / 2),   25, controls.L4, font)
			lcd.drawText(200 - (lcd.getTextWidth(font, controls.L5) / 2),   46, controls.L5, font)
			lcd.drawText(200 - (lcd.getTextWidth(font, controls.L6) / 2),   67, controls.L6, font)
			lcd.drawText(200 - (lcd.getTextWidth(font, controls.L7) / 2),   88, controls.L7, font)
		else
			lcd.drawText(290 - lcd.getTextWidth(font, controls.L3),   4,  controls.L3, font)
			lcd.drawText(290 - lcd.getTextWidth(font, controls.L4),   25, controls.L4, font)
			lcd.drawText(290 - lcd.getTextWidth(font, controls.L5),   46, controls.L5, font)
			lcd.drawText(290 - lcd.getTextWidth(font, controls.L6),   67, controls.L6, font)
			lcd.drawText(290 - lcd.getTextWidth(font, controls.L7),   88, controls.L7, font)	
		end
	end
end

-------------------------------------------------------------------------------
-- Ansicht hinten rechts

local function drawPageRB(width, height)
	local font
	lcd.setColor(255, 255, 255)

	if (device == "JETI DC-24 II" or device == "JETI DS-24 II") then

		if (imageRB == nil) then
			imageRB = loadImage("DC24-2_Schalter_R_RS")
		end

		if (imageRB) then
			lcd.drawImage(0, 0, imageRB)
		end
		
		font = FONT_BOLD
				lcd.drawText(3, 5,  "R3", font)
				lcd.drawText(3, 26,  "R4", font)
				lcd.drawText(3, 48,  "R5", font)
				lcd.drawText(3, 68,  "R6", font)
				lcd.drawText(3, 90,  "R7", font)

		font = FONT_NORMAL
			if (centerR) then	
				lcd.drawText(118 - (lcd.getTextWidth(font, controls.R3) / 2),  4,  controls.R3, font)
				lcd.drawText(118 - (lcd.getTextWidth(font, controls.R4) / 2),  25, controls.R4, font)
				lcd.drawText(118 - (lcd.getTextWidth(font, controls.R5) / 2),  46, controls.R5, font)
				lcd.drawText(118 - (lcd.getTextWidth(font, controls.R6) / 2),  67, controls.R6, font)
				lcd.drawText(118 - (lcd.getTextWidth(font, controls.R7) / 2),  88, controls.R7, font)
			else
				lcd.drawText(26, 4,   controls.R3, font)
				lcd.drawText(26, 25,  controls.R4, font)
				lcd.drawText(26, 46,  controls.R5, font)
				lcd.drawText(26, 67,  controls.R6, font)
				lcd.drawText(26, 88,  controls.R7, font)
			end

	end
end

-------------------------------------------------------------------------------------------------------Telemetriefenster 1
local function drawPageL(width, height)
	local  method = value == 1 and drawPageLB or drawPageLA
	return method(width, height)
end

-- ---------------------------------------------------------------------------------------------------Telemetriefenster 2
local function drawPageR(width, height)
	local  method = value == 1 and drawPageRB or drawPageRA
	return method(width, height)
end
--------------------------------------------------------------------------------

local function initForm(subform)

  form.setButton(1, ":tools", DISABLED)
	form.setButton(2, ":file",    timeB2 and HIGHLIGHTED or ENABLED)
	form.setButton(3, ":refresh", timeB3 and HIGHLIGHTED or ENABLED) --- hier muss geladen werden
	form.setButton(4, ":edit",    timeB4 and HIGHLIGHTED or ENABLED) --- hier muss gespeichert werden
	
	formID = subform

	form.addRow(2)
	form.addLabel({label=trans.newdesign, width=275})
	formGrafik = form.addCheckbox(neuegrafik, function(value) 
		neuegrafik = not value
		system.pSave("neuegrafik", neuegrafik and 1 or 0)
		form.setValue(formGrafik, neuegrafik)
		collectgarbage()
	end)

  form.addRow(2)
  form.addLabel({label=trans.toggle, width=260})
  form.addInputbox(switch, true, function(value)
		switch = value
		system.pSave("switch", value)
	end)
	
	form.addRow(2)                                         
	form.addLabel({label=trans.centerupperleft, width=275})
		formCenterL = form.addCheckbox(centerL, function(value) 
		  centerL = not value
			system.pSave("centerL", centerL and 1 or 0)
			form.setValue(formCenterL, centerL)
		end)
		
	form.addRow(2)                                         
	form.addLabel({label=trans.centerupperright, width=275})
	  formCenterR = form.addCheckbox(centerR, function(value)    
			centerR = not value
			system.pSave("centerR", centerR and 1 or 0)
			form.setValue(formCenterR, centerR)
		end)
		
	form.addSpacer(300,10)
	form.addLabel({label=trans.switchlabeling, font=FONT_BOLD}) 
		

	form.addRow(2)
	form.addLabel({label=trans.selectswitch, width=250})
	form.addSelectbox(options, option, true, function(value)
		option = value
		text   = controls[options[option]]
		form.reinit(formID)
		end)
		
		form.addRow(2)
		form.addLabel({label=trans.label})
		form.addTextbox(text, 26, function(value)
			text = value
			controls[options[option]] = text
		end)				

		form.addSpacer(300,10)
		form.addLabel({label=trans.stickswitchlabel, font=FONT_BOLD}) 
		form.addRow(2)
		form.addLabel({label=trans.stickswitch_l_front,font=FONT_MINI, width=250})	
		form.addSelectbox(options, knueppelnameLV, true, function(value)
		knueppelnameLV = value
			system.pSave("knueppelnameLV", value)
		end																										
		)

		form.addRow(2)
		form.addLabel({label=trans.stickswitch_l_top,font=FONT_MINI, width=250})	
		form.addSelectbox(options, knueppelnameLO, true, function(value)
		knueppelnameLO = value
			system.pSave("knueppelnameLO", value)
		end																										
		)

		form.addRow(2)
		form.addLabel({label=trans.stickswitch_r_front,font=FONT_MINI, width=250})	
		form.addSelectbox(options, knueppelnameRV, true, function(value)
		knueppelnameRV = value
			system.pSave("knueppelnameRV", value)
		end																										
		)

		form.addRow(2)
		form.addLabel({label=trans.stickswitch_r_top,font=FONT_MINI, width=250})	
		form.addSelectbox(options, knueppelnameRO, true, function(value)
			knueppelnameRO = value
			system.pSave("knueppelnameRO", value)
		end																										
		)

		form.addSpacer(300,10)
		form.addLabel({label= appnamen .. "   V.".. appversion .. "       [Redesign by Klaus Geiger]",font=FONT_MINI, alignRight=true})
		form.addRow(1)

end


--------------------------------------------------------------------------------
local function loop()
	value = system.getInputsVal(switch)
	
	if (timeB2 or timeB3 or timeB4) then
		local time  = system.getTimeCounter()
		local limit = 1000

		if (timeB2 and time - timeB2 > limit) then
			timeB2 = nil
			form.setButton(2, ":file", ENABLED)
		end
		
		if (timeB3 and time - timeB3 > limit) then
			timeB3 = nil
			form.setButton(3, ":refresh", ENABLED)
		end

		if (timeB4 and time - timeB4 > limit) then
			timeB4 = nil
			form.setButton(4, ":edit", ENABLED)
		end
	end
end

--------------------------------------------------------------------------------
local function keyForm(key)
	if (key == KEY_1 and formID ~= 1) then
		form.reinit(1)
	elseif (key == KEY_2) then
		timeB2 = system.getTimeCounter()
		initModel()
		form.reinit(formID)
	elseif (key == KEY_3) then
		timeB3 = system.getTimeCounter()
		loadModel()
		form.reinit(formID)
	elseif (key == KEY_4) then
		timeB4 = system.getTimeCounter()
		saveModel()
		form.reinit(formID)
	end
end

--------------------------------------------------------------------------------
local function init(code)
																										
	local pLoad, registerForm, registerTelemetry = system.pLoad, system.registerForm, system.registerTelemetry

	neuegrafik = pLoad("neuegrafik", 0) == 1
	knueppelnameLV     = pLoad("knueppelnameLV", 37) -- 37 = CH1
	knueppelnameLO     = pLoad("knueppelnameLO", 11) -- 11 = SK
	knueppelnameRV     = pLoad("knueppelnameRV", 38) -- 38 = CH2
	knueppelnameRO     = pLoad("knueppelnameRO", 12) -- 12 = SL
	model   = system.getProperty("Model")
	device  = system.getDeviceType()
	switch  = system.pLoad("switch")
	centerL = pLoad("centerL", 0) == 1																										
	centerR = pLoad("centerR", 0) == 1
	options = {"SA", "SB", "SC", "SD", "SE", "SF", "SG", "SH", "SI", "SJ", "SK", "SL", "SM", "SN", "SO", "SP", "L1", "L2", "L3", "L4", "L5", "L6", "L7", "R1", "R2", "R3", "R4", "R5", "R6", "R7", "G5", "G6", "G7", "G8", "G9", "G10", "CH1", "CH2", "CH3", "CH4", "CH5", "CH6", "CH7", "CH8" } 
	
	loadModel()
	
	registerForm(1, MENU_MAIN, "Switch57", initForm, keyForm)
	registerTelemetry(1, "Switch57 "..model.." left" , 4, drawPageL)
	registerTelemetry(2, "Switch57 "..model.." right", 4, drawPageR)

	collectgarbage()
end
--------------------------------------------------------------------------------
setLanguage()
collectgarbage()
return {init=init, loop=loop, author="IG-Development Ingmar Grote", version=appversion, name=appnamen}
